Description: Introduce build Makefile
  This Makefile can build the two fonts and autohint them in parallel. This
  is introduced because it would have been too complicated to put into the
  debian/rules file.

  This is not proposed to upstream, because they introduce release scripts
  that are today not possible to run on Debian because of missing dependencies.

  If this patch can run the same set of tools than upstream and meet their
  way of working, it shall then be proposed.

Forwarded: not-needed
Author: Romain Porte <debian@microjoe.org>

---

Origin: vendor
Forwarded: not-needed
Last-Update: 2020-11-18

--- /dev/null
+++ fonts-jetbrains-mono-2.210/Makefile
@@ -0,0 +1,37 @@
+FONT := JetBrainsMono
+DEST := $(DESTDIR)/usr/share/fonts/truetype/jetbrains-mono
+
+VARIANTS := Bold ExtraBold ExtraLight Light Medium Thin
+NORMAL_VARIANTS := $(VARIANTS) Regular
+ITALIC_VARIANTS := $(VARIANTS)
+
+NORMAL_GEN := sources/$(FONT).gen
+NORMAL_FONTS := $(foreach v,$(NORMAL_VARIANTS),$(NORMAL_GEN)/$(FONT)-$(v).ttf)
+HINTED_NORMAL_FONTS := $(addsuffix .hinted,$(NORMAL_FONTS))
+
+ITALIC_GEN := sources/$(FONT)-Italic.gen
+ITALIC_FONTS := $(foreach v,$(ITALIC_VARIANTS),$(ITALIC_GEN)/$(FONT)-$(v)Italic.ttf)
+HINTED_ITALIC_FONTS := $(addsuffix .hinted,$(ITALIC_FONTS))
+
+all: normal italic
+
+%.gen: %.glyphs
+	fontmake -g $< -i -o ttf --output-dir $@ \
+		--master-dir $<.ufo_master --instance-dir $<.ufo_instance
+
+normal: $(HINTED_NORMAL_FONTS)
+italic: $(HINTED_ITALIC_FONTS)
+
+$(NORMAL_FONTS): $(NORMAL_GEN)
+$(ITALIC_FONTS): $(ITALIC_GEN)
+
+%.ttf.hinted: %.ttf
+	ttfautohint $< $@
+
+install:
+	install -d $(DEST)
+	$(foreach f,$(NORMAL_FONTS) $(ITALIC_FONTS),install -m0644 $(f).hinted $(DEST)/$(notdir $(f));)
+
+clean:
+	rm -rf $(NORMAL_GEN) $(ITALIC_GEN) sources/*.ufo_master sources/*.ufo_instance
+
